about summary refs log tree commit diff
diff options
context:
space:
mode:
authorThomas Schwinge <thomas@codesourcery.com>2013-05-26 20:58:06 +0200
committerThomas Schwinge <thomas@codesourcery.com>2013-08-29 12:22:17 +0200
commitc54290cf086940e3859b236d0fb880bacab2288b (patch)
tree66a48e6382f61753f8b35788689c105bd79ccc28
parent0007fc9bdd1d9efcd52d07837f2cd085b5a8f58b (diff)
downloadglibc-c54290cf086940e3859b236d0fb880bacab2288b.tar.gz
glibc-c54290cf086940e3859b236d0fb880bacab2288b.tar.xz
glibc-c54290cf086940e3859b236d0fb880bacab2288b.zip
Use ELFOSABI_GNU instead of ELFOSABI_LINUX.
-rw-r--r--ChangeLog4
-rw-r--r--ports/ChangeLog.arm6
-rw-r--r--ports/ChangeLog.mips5
-rw-r--r--ports/sysdeps/unix/sysv/linux/arm/ldsodefs.h6
-rw-r--r--ports/sysdeps/unix/sysv/linux/mips/ldsodefs.h4
-rw-r--r--sysdeps/unix/sysv/linux/ldsodefs.h8
6 files changed, 24 insertions, 9 deletions
diff --git a/ChangeLog b/ChangeLog
index 7c1625e87a..a45e2e2dbb 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,5 +1,9 @@
 2013-08-29  Thomas Schwinge  <thomas@codesourcery.com>
 
+	* sysdeps/unix/sysv/linux/ldsodefs.h (VALID_ELF_OSABI)
+	(VALID_ELF_ABIVERSION, MORE_ELF_HEADER_DATA): Use ELFOSABI_GNU
+	instead of ELFOSABI_LINUX.
+
 	[BZ #15522] strtod ("nan(N)") returning a sNaN in some cases
 
 	* stdlib/strtof_l.c (SET_MANTISSA): Rewrite.
diff --git a/ports/ChangeLog.arm b/ports/ChangeLog.arm
index 52f7c0f726..6dad08da30 100644
--- a/ports/ChangeLog.arm
+++ b/ports/ChangeLog.arm
@@ -1,3 +1,9 @@
+2013-08-29  Thomas Schwinge  <thomas@codesourcery.com>
+
+	* sysdeps/unix/sysv/linux/arm/ldsodefs.h (VALID_ELF_OSABI)
+	(MORE_ELF_HEADER_DATA): Use ELFOSABI_GNU instead of
+	ELFOSABI_LINUX.
+
 2013-08-28  Kyle McMartin  <kyle@redhat.com>
 	    Carlos O'Donell  <carlos@redhat.com>
 
diff --git a/ports/ChangeLog.mips b/ports/ChangeLog.mips
index e61b022ebd..7509c774de 100644
--- a/ports/ChangeLog.mips
+++ b/ports/ChangeLog.mips
@@ -1,3 +1,8 @@
+2013-08-29  Thomas Schwinge  <thomas@codesourcery.com>
+
+	* sysdeps/unix/sysv/linux/mips/ldsodefs.h (VALID_ELF_ABIVERSION):
+	Use ELFOSABI_GNU instead of ELFOSABI_LINUX.
+
 2013-08-29   Ondřej Bílka  <neleai@seznam.cz>
 
 	* sysdeps/mips/sys/asm.h: Fix typos.
diff --git a/ports/sysdeps/unix/sysv/linux/arm/ldsodefs.h b/ports/sysdeps/unix/sysv/linux/arm/ldsodefs.h
index 50a8bb7644..3821bf33b3 100644
--- a/ports/sysdeps/unix/sysv/linux/arm/ldsodefs.h
+++ b/ports/sysdeps/unix/sysv/linux/arm/ldsodefs.h
@@ -44,8 +44,8 @@
     || memcmp (hdr, expected3, size) == 0)	\
    && VALID_FLOAT_ABI (ehdr->e_flags))
 #define VALID_ELF_OSABI(osabi)		(osabi == ELFOSABI_SYSV		\
-					 || osabi == EXTRA_OSABI	\
-					 || osabi == ELFOSABI_LINUX)
+					 || osabi == ELFOSABI_GNU	\
+					 || osabi == EXTRA_OSABI)
 #define MORE_ELF_HEADER_DATA				\
   static const unsigned char expected2[EI_PAD] =	\
   {							\
@@ -56,7 +56,7 @@
     [EI_CLASS] = ELFW(CLASS),				\
     [EI_DATA] = byteorder,				\
     [EI_VERSION] = EV_CURRENT,				\
-    [EI_OSABI] = ELFOSABI_LINUX				\
+    [EI_OSABI] = ELFOSABI_GNU				\
   };							\
   static const unsigned char expected3[EI_PAD] =	\
   {							\
diff --git a/ports/sysdeps/unix/sysv/linux/mips/ldsodefs.h b/ports/sysdeps/unix/sysv/linux/mips/ldsodefs.h
index eb45f7229a..76c38c8d29 100644
--- a/ports/sysdeps/unix/sysv/linux/mips/ldsodefs.h
+++ b/ports/sysdeps/unix/sysv/linux/mips/ldsodefs.h
@@ -30,11 +30,11 @@ extern void _dl_static_init (struct link_map *map);
 #define DL_STATIC_INIT(map) _dl_static_init (map)
 
 /* Allow ABIVERSION == 1, meaning PLTs and copy relocations are
-   required, with ELFOSABI_SYSV.  */
+   required, with ELFOSABI_SYSV, and ELFOSABI_GNU.  */
 #undef VALID_ELF_ABIVERSION
 #define VALID_ELF_ABIVERSION(osabi,ver)			\
   (ver == 0						\
    || (osabi == ELFOSABI_SYSV && ver < 2)		\
-   || (osabi == ELFOSABI_LINUX && ver < LIBC_ABI_MAX))
+   || (osabi == ELFOSABI_GNU && ver < LIBC_ABI_MAX))
 
 #endif /* ldsodefs.h */
diff --git a/sysdeps/unix/sysv/linux/ldsodefs.h b/sysdeps/unix/sysv/linux/ldsodefs.h
index 18ff8528c2..c1b1543ab2 100644
--- a/sysdeps/unix/sysv/linux/ldsodefs.h
+++ b/sysdeps/unix/sysv/linux/ldsodefs.h
@@ -41,13 +41,13 @@
    up the page size information.  */
 #define HAVE_AUX_PAGESIZE
 
 /* Accept binaries which identify the binary as using Linux extensions.  */
 #define VALID_ELF_HEADER(hdr,exp,size)	(memcmp (hdr, exp, size) == 0	\
 					 || memcmp (hdr, expected2, size) == 0)
 #define VALID_ELF_OSABI(osabi)		(osabi == ELFOSABI_SYSV \
-					 || osabi == ELFOSABI_LINUX)
+					 || osabi == ELFOSABI_GNU)
 #define VALID_ELF_ABIVERSION(osabi,ver) \
-  (ver == 0 || (osabi == ELFOSABI_LINUX && ver < LIBC_ABI_MAX))
+  (ver == 0 || (osabi == ELFOSABI_GNU && ver < LIBC_ABI_MAX))
 #define MORE_ELF_HEADER_DATA \
   static const unsigned char expected2[EI_PAD] =	\
   {							\
@@ -58,7 +58,7 @@
     [EI_CLASS] = ELFW(CLASS),				\
     [EI_DATA] = byteorder,				\
     [EI_VERSION] = EV_CURRENT,				\
-    [EI_OSABI] = ELFOSABI_LINUX				\
+    [EI_OSABI] = ELFOSABI_GNU				\
   }
 
 #endif /* ldsodefs.h */
@@ -41,13 +41,13 @@
 #define HAVE_AUX_PAGESIZE
 
-/* Accept binaries which identify the binary as using Linux extensions.  */
+/* Accept binaries which identify the binary as using GNU extensions.  */
 #define VALID_ELF_HEADER(hdr,exp,size)	(memcmp (hdr, exp, size) == 0	\
 					 || memcmp (hdr, expected2, size) == 0)